package LATMOS::Accounts::Bases::Dummy::User;

use strict;
use warnings;
use base qw(LATMOS::Accounts::Bases::Objects);

=head1 NAME

LATMOS::Accounts::Bases::Dummy::User - User support for Dummy base

=cut

our $VERSION = (q$Rev: 1350 $ =~ /^Rev: (\d+) /)[0];

sub _get_attr_schema {
    {
        username => {},
        homeDirectory => { iname => 'home' },
        shell => {},
        gecos => {},
        uidNumber => {},
        gidNumber => {},
    }
}

sub list {
    return ();
}

sub new {
    my ($class, $base, $id) = @_;
    bless { _id => $id, base => $base }, $class;
}

sub id {
    shift->{_id};
}

sub _create {
    my ($class, $base, $id, %data) = @_;

    my $obj = __PACKAGE__->new($base, $id);
    $obj->set_field(%data, username => $id);

    return 1;
}

sub get_field {
    my ($self, $attr) = @_;

    $self->{base}{objects}{user}{$self->id}{$attr}
}

sub set_field {
    my ($self, %data) = @_;

    my $attrs = $self->_get_attr_schema;

    foreach (keys %data) {
        my $attr = $attrs->{$_}{iname} || $_;
        $self->{base}{objects}{user}{$self->id}{$attr} = $data{$_};
    }

    return 1,
}

1;

__END__

=head1 SEE ALSO

L<LATMOS::Accounts::Bases::Sql>, L<LATMOS::Accounts::Bases::Sql::DataRequest>

=head1 AUTHOR

Olivier Thauvin, E<lt>olivier.thauvin@latmos.ipsl.frE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008, 2009, 2010, 2011, 2012 CNRS SA/CETP/LATMOS

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.0 or,
at your option, any later version of Perl 5 you may have available.

=cut
